==> black_hole_flutter-0.2.8.tar.gz: example/lib/buttons.dart <==
import 'package:black_hole_flutter/black_hole_flutter.dart';
import 'package:flutter/material.dart';

import 'main.dart';

class ButtonsExample extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Section(
      title: 'Buttons',
      children: [
        SingleChildScrollView(
          scrollDirection: Axis.horizontal,
          child: Padding(
            // We don't want to crop shadows.
            padding: EdgeInsets.only(right: 12, bottom: 12),
            child: Table(
              defaultColumnWidth: IntrinsicColumnWidth(),
              defaultVerticalAlignment: TableCellVerticalAlignment.middle,
              children: [
                _buildRow('Widget', [
                  Text('default'),
                  Text('onPressed: null'),
                  Text('isEnabled: false'),
                  Text('isLoading: true,\nloadingChild: null'),
                  Text('isLoading: true'),
                ]),
                _buildSpacerRow(),
                _buildFancyFlatButtonRow(),
                _buildSpacerRow(),
                _buildFancyIconFlatButtonRow(),
                _buildSpacerRow(),
                _buildFancyOutlineButtonRow(),
                _buildSpacerRow(),
                _buildFancyIconOutlineButtonRow(),
                _buildSpacerRow(),
                _buildFancyRaisedButtonRow(),
                _buildSpacerRow(),
                _buildFancyIconRaisedButtonRow(),
                _buildSpacerRow(),
                _buildFancyFabRow(),
                _buildSpacerRow(),
                _buildExtendedFancyFabRow(),
              ],
            ),
          ),
        )
      ],
    );
  }

  TableRow _buildFancyFlatButtonRow() => _buildRow('FancyFlatButton', [
        FancyFlatButton(
          onPressed: () {},
          child: Text('child'),
        ),
        FancyFlatButton(
          onPressed: null,
          child: Text('child'),
        ),
        FancyFlatButton(
          isEnabled: false,
          onPressed: () {},
          child: Text('child'),
        ),
        FancyFlatButton(
          onPressed: () {},
          isLoading: true,
          child: Text('child'),
        ),
        FancyFlatButton(
          onPressed: () {},
          isLoading: true,
          loadingChild: Text('loadingChild'),
          child: Text('child'),
        ),
      ]);
  TableRow _buildFancyIconFlatButtonRow() => _buildRow('FancyFlatButton.icon', [
        FancyFlatButton.icon(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFlatButton.icon(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFlatButton.icon(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFlatButton.icon(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFlatButton.icon(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildFancyOutlineButtonRow() => _buildRow('FancyOutlineButton', [
        FancyOutlineButton(
          onPressed: () {},
          child: Text('child'),
        ),
        FancyOutlineButton(
          onPressed: null,
          child: Text('child'),
        ),
        FancyOutlineButton(
          isEnabled: false,
          onPressed: () {},
          child: Text('child'),
        ),
        FancyOutlineButton(
          onPressed: () {},
          isLoading: true,
          child: Text('child'),
        ),
        FancyOutlineButton(
          onPressed: () {},
          isLoading: true,
          loadingChild: Text('loadingChild'),
          child: Text('child'),
        ),
      ]);
  TableRow _buildFancyIconOutlineButtonRow() =>
      _buildRow('FancyOutlineButton.icon', [
        FancyOutlineButton.icon(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlineButton.icon(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlineButton.icon(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlineButton.icon(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlineButton.icon(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildFancyRaisedButtonRow() => _buildRow('FancyRaisedButton', [
        FancyRaisedButton(
          onPressed: () {},
          child: Text('child'),
        ),
        FancyRaisedButton(
          onPressed: null,
          child: Text('child'),
        ),
        FancyRaisedButton(
          isEnabled: false,
          onPressed: () {},
          child: Text('child'),
        ),
        FancyRaisedButton(
          onPressed: () {},
          isLoading: true,
          child: Text('child'),
        ),
        FancyRaisedButton(
          onPressed: () {},
          isLoading: true,
          loadingChild: Text('loadingChild'),
          child: Text('child'),
        ),
      ]);
  TableRow _buildFancyIconRaisedButtonRow() =>
      _buildRow('FancyRaisedButton.icon', [
        FancyRaisedButton.icon(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyRaisedButton.icon(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyRaisedButton.icon(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyRaisedButton.icon(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyRaisedButton.icon(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildFancyFabRow() => _buildRow('FancyFab', [
        FancyFab(
          onPressed: () {},
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          onPressed: null,
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          isEnabled: false,
          onPressed: () {},
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          onPressed: () {},
          isLoading: true,
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          child: Icon(Icons.favorite),
        ),
      ]);
  TableRow _buildExtendedFancyFabRow() => _buildRow('FancyFab.extended', [
        FancyFab.extended(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildRow(String title, List<Widget> children) {
    return TableRow(children: [
      // SizedBox(width: 8),
      Text(title),
      for (final child in children) ...[
        SizedBox(width: 8),
        Center(child: child),
      ],
      // SizedBox(width: 8),
    ]);
  }

  TableRow _buildSpacerRow() =>
      TableRow(children: List.filled(11, SizedBox(height: 8)));
}

==> black_hole_flutter-0.3.0.tar.gz: example/lib/buttons.dart <==
import 'package:black_hole_flutter/black_hole_flutter.dart';
import 'package:flutter/material.dart';

import 'main.dart';

class ButtonsExample extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Section(
      title: 'Buttons',
      children: [
        SingleChildScrollView(
          scrollDirection: Axis.horizontal,
          child: Padding(
            // We don't want to crop shadows.
            padding: EdgeInsets.only(right: 12, bottom: 12),
            child: Table(
              defaultColumnWidth: IntrinsicColumnWidth(),
              defaultVerticalAlignment: TableCellVerticalAlignment.middle,
              children: [
                _buildRow('Widget', [
                  Text('default'),
                  Text('onPressed: null'),
                  Text('isEnabled: false'),
                  Text('isLoading: true,\nloadingChild: null'),
                  Text('isLoading: true'),
                ]),
                _buildSpacerRow(),
                _buildFancyTextButtonRow(),
                _buildSpacerRow(),
                _buildFancyIconFlatButtonRow(),
                _buildSpacerRow(),
                _buildFancyOutlinedButtonRow(),
                _buildSpacerRow(),
                _buildFancyIconOutlineButtonRow(),
                _buildSpacerRow(),
                _buildFancyElevatedButtonRow(),
                _buildSpacerRow(),
                _buildFancyIconRaisedButtonRow(),
                _buildSpacerRow(),
                _buildFancyFabRow(),
                _buildSpacerRow(),
                _buildExtendedFancyFabRow(),
              ],
            ),
          ),
        )
      ],
    );
  }

  TableRow _buildFancyTextButtonRow() => _buildRow('FancyTextButton', [
        FancyTextButton(
          onPressed: () {},
          child: Text('child'),
        ),
        FancyTextButton(
          onPressed: null,
          child: Text('child'),
        ),
        FancyTextButton(
          isEnabled: false,
          onPressed: () {},
          child: Text('child'),
        ),
        FancyTextButton(
          onPressed: () {},
          isLoading: true,
          child: Text('child'),
        ),
        FancyTextButton(
          onPressed: () {},
          isLoading: true,
          loadingChild: Text('loadingChild'),
          child: Text('child'),
        ),
      ]);
  TableRow _buildFancyIconFlatButtonRow() => _buildRow('FancyTextButton.icon', [
        FancyTextButton.icon(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyTextButton.icon(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyTextButton.icon(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyTextButton.icon(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyTextButton.icon(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildFancyOutlinedButtonRow() => _buildRow('FancyOutlinedButton', [
        FancyOutlinedButton(
          onPressed: () {},
          child: Text('child'),
        ),
        FancyOutlinedButton(
          onPressed: null,
          child: Text('child'),
        ),
        FancyOutlinedButton(
          isEnabled: false,
          onPressed: () {},
          child: Text('child'),
        ),
        FancyOutlinedButton(
          onPressed: () {},
          isLoading: true,
          child: Text('child'),
        ),
        FancyOutlinedButton(
          onPressed: () {},
          isLoading: true,
          loadingChild: Text('loadingChild'),
          child: Text('child'),
        ),
      ]);
  TableRow _buildFancyIconOutlineButtonRow() =>
      _buildRow('FancyOutlinedButton.icon', [
        FancyOutlinedButton.icon(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlinedButton.icon(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlinedButton.icon(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlinedButton.icon(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyOutlinedButton.icon(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildFancyElevatedButtonRow() => _buildRow('FancyElevatedButton', [
        FancyElevatedButton(
          onPressed: () {},
          child: Text('child'),
        ),
        FancyElevatedButton(
          onPressed: null,
          child: Text('child'),
        ),
        FancyElevatedButton(
          isEnabled: false,
          onPressed: () {},
          child: Text('child'),
        ),
        FancyElevatedButton(
          onPressed: () {},
          isLoading: true,
          child: Text('child'),
        ),
        FancyElevatedButton(
          onPressed: () {},
          isLoading: true,
          loadingChild: Text('loadingChild'),
          child: Text('child'),
        ),
      ]);
  TableRow _buildFancyIconRaisedButtonRow() =>
      _buildRow('FancyElevatedButton.icon', [
        FancyElevatedButton.icon(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyElevatedButton.icon(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyElevatedButton.icon(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyElevatedButton.icon(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyElevatedButton.icon(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildFancyFabRow() => _buildRow('FancyFab', [
        FancyFab(
          onPressed: () {},
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          onPressed: null,
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          isEnabled: false,
          onPressed: () {},
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          onPressed: () {},
          isLoading: true,
          child: Icon(Icons.favorite),
        ),
        FancyFab(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          child: Icon(Icons.favorite),
        ),
      ]);
  TableRow _buildExtendedFancyFabRow() => _buildRow('FancyFab.extended', [
        FancyFab.extended(
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          onPressed: null,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          isEnabled: false,
          onPressed: () {},
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          onPressed: () {},
          isLoading: true,
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
        FancyFab.extended(
          onPressed: () {},
          isLoading: true,
          loadingLabel: Text('loadingLabel'),
          label: Text('label'),
          icon: Icon(Icons.favorite),
        ),
      ]);

  TableRow _buildRow(String title, List<Widget> children) {
    return TableRow(children: [
      // SizedBox(width: 8),
      Text(title),
      for (final child in children) ...[
        SizedBox(width: 8),
        Center(child: child),
      ],
      // SizedBox(width: 8),
    ]);
  }

  TableRow _buildSpacerRow() =>
      TableRow(children: List.filled(11, SizedBox(height: 8)));
}
